class Color:
    WHITE = "#ffffff"
    BLACK = "#000000"

    BLUE = "#0050A0"
    BLUE_DARK = "#092B61"
    BLUE_LIGHT = "#3A8FE4"

    YELLOW = "#E5B700"
    YELLOW_DARK = "#CE9A0E"
    YELLOW_LIGHT = "#FFE066"

    ORANGE = "#FF8029"
    ORANGE_DARK = "#DC5900"
    ORANGE_LIGHT = "#FFC29D"

    RED = "#E84A33"
    RED_DARK = "#A4220F"
    RED_LIGHT = "#F48D7E"

    BROWN = "#84451E"
    BROWN_DARK = "#59280A"
    BROWN_LIGHT = "#A56034"

    PINK = "#E961B9"
    PINK_DARK = "#A91374"
    PINK_LIGHT = "#F6B0DD"

    PURPLE = "#A957BE"
    PURPLE_DARK = "#7C2377"
    PURPLE_LIGHT = "#E093F4"

    VIOLET = "#4E326C"  # More dark purple
    VIOLET_DARK = "#3C124C"
    VIOLET_LIGHT = "#9C7DBE"

    CYAN = "#3DCFCF"
    CYAN_DARK = "#1A7C7F"
    CYAN_LIGHT = "#80E2E5"

    GREEN = "#60AE60"
    GREEN_DARK = "#2E6E2E"
    GREEN_LIGHT = "#95D395"

    GREY = "#808080"
    GREY_DARK = "#202020"
    GREY_LIGHT = "#A2A2A2"
